slepc-3.18.0 2022-10-01
Report Typos and Errors

# RGRegister

Adds a region to the RG package.

### Synopsis

    #include "slepcrg.h"
    PetscErrorCode RGRegister(const char *name,PetscErrorCode (*function)(RG))

Not collective

### Input Parameters

| name | - name of a new user-defined RG
| function | - routine to create context

### Notes

RGRegister() may be called multiple times to add several user-defined regions.

### See Also

RGRegisterAll()

### Level

advanced

### Location

src/sys/classes/rg/rgbasic.c
Index of all RG routines
Table of Contents for all manual pages
Index of all manual pages